@@ -53,25 +53,41 @@ class WorkflowContextManager(API):
         self._email = email
         self._mark_as_complete_after_polling = mark_as_complete_after_polling
 
+    @property
+    def dataset(self) -> Dataset:
+        return self._dataset
+
+    @property
+    def field_children_metadata(self) -> Dict[str, str]:
+        script_path = os.getenv("script_path", "")
+        workflow_id = script_path.split("/")[0]
+        return {
+            "job_id": self._job_id,
+            "workflow_id": workflow_id,
+        }
+
     def __enter__(self):
         """
         The workflow is in progress
         """
-        for operator in self._operators:
-            if operator.update_field_children:
-                for input_field in operator.input_fields:
-                    res = self.set_field_children(
-                        input_field=input_field,
-                        output_fields=operator.output_fields,
-                        fieldchildren_id=self._job_id,
-                    )
-                    logger.debug(format_logging_info(res))
-
+        self._set_field_children_recursively()
         self._set_status(
             status=self.IN_PROGRESS, worker_number=self._engine.worker_number
         )
         return
 
+    def _set_field_children_recursively(self):
+        for operator in self._operators:
+            if operator.update_field_children:
+                for input_field in operator.input_fields:
+                    res = self.dataset[input_field].add_field_children(
+                        field_children=operator.output_fields,
+                        fieldchildren_id=self._job_id,
+                        metadata=self.field_children_metadata,
+                        recursive=True,
+                    )
+                    logger.debug(format_logging_info(res))
+
     def _handle_workflow_fail(
         self, exc_type: type, exc_value: BaseException, traceback: Traceback
     ):
@@ -93,7 +109,7 @@ class WorkflowContextManager(API):
             result = self._trigger_polling_workflow(
                 dataset_id=self._dataset_id,
                 input_field=self._operators[0].input_fields[0],
-                output_field=self._operators[-1].output_fields[0],
+                output_field=self._operators[-1].output_fields[-1],
                 job_id=self._job_id,
                 workflow_name=self._workflow_name,
             )
@@ -113,21 +129,6 @@ class WorkflowContextManager(API):
         else:
             return self._handle_workflow_complete(exc_type, exc_value, traceback)
 
-    def set_field_children(
-        self, input_field: str, output_fields: list, fieldchildren_id: str
-    ):
-        # Implement the config ID and authorization token
-        # Receive these from the env variables in production - do not touch
-        script_path = os.getenv("script_path", "")
-        metadata = {"job_id": self._job_id, "workflow_id": script_path.split("/")[0]}
-        return self._set_field_children(
-            dataset_id=self._dataset_id,
-            field=input_field,
-            field_children=output_fields,
-            metadata=metadata,
-            fieldchildren_id=fieldchildren_id,
-        )
-
     def _set_status(
         self,
         status: str,
